.. _SASS: http://sass-lang.com/
.. _LibSass: http://sass-lang.com/libsass
.. _Watchdog: https://github.com/gorakhargosh/watchdog
.. _click: http://click.pocoo.org/5/
.. _libsass-python: https://github.com/dahlia/libsass-python
.. _colorama: https://github.com/tartley/colorama
.. _colorlog: https://github.com/borntyping/python-colorlog
.. _six: https://pythonhosted.org/six/
.. _pyaml: https://github.com/mk-fg/pretty-yaml

========
Boussole
========

Features
********

* Stand on `LibSass`_ which is **very fast**;
* **Per project configuration** so you can use it once to compile all of your
  Sass files from a same project;
* **Simple and useful** command line;
* **Watch mode** for no waste of time during web design integration;
* **Full Python stack**, no Ruby or Node.js stuff needed;
* **Expose a Core API** to use it from Python code;
* Support **Python>=3.5**;

Links
*****

* Read the documentation on `Read the docs <https://boussole.readthedocs.io/>`_;
* Download its `PyPi package <https://pypi.org/project/boussole/>`_;
* Clone it on its `Github repository <https://github.com/sveetch/boussole>`_;

Dependancies
************

* `click`_ >=5.1;
* `colorama`_;
* `colorlog`_;
* `libsass-python`_ >=0.19.4;
* `pyaml`_;
* `Watchdog`_ >=0.8.3;

Credits
*******

Logo has been created by **Sébastien Bianco**.
